@@ -1,6 +1,9 @@
 from typing import Callable
+
+import rpyc
 from rpyc import async_
-from linien.common import unpack, pack
+
+from linien.common import pack, unpack
 
 
 class RemoteParameters:
@@ -92,13 +95,15 @@ class RemoteParameters:
         # when directly iterating over `exposed_init_parameter_sync`, each iteration
         # triggers a request as it is a netref over an iterator
         # --> the `list` call prevents this and improves startup performance
-        all_parameters = list(self.remote.exposed_init_parameter_sync(self.uuid))
+        all_parameters = unpack(self.remote.exposed_init_parameter_sync(self.uuid))
 
         for name, param, value, can_be_cached in all_parameters:
             param = RemoteParameter(self, param, name, use_cache and can_be_cached)
             setattr(self, name, param)
             if use_cache and can_be_cached:
-                param._update_cache(value)
+                # obtain takes care that we really don't deal with netrefs
+                # (np.float64 is not automatically serialized)
+                param._update_cache(rpyc.classic.obtain(value))
 
         self._attributes_locked = True
 
